@@ -3,7 +3,6 @@
 import asyncio
 import click
 import csv
-import curses
 import glob
 import importlib
 import logging
@@ -13,6 +12,8 @@ import re
 import subprocess
 import sys
 import tempfile
+import termios
+import tty
 
 # idrc_esp_tools modules
 from .idrc_esp_tools import analyze_nvs, serial_asyncio, at
@@ -29,25 +30,17 @@ NVS_TARGET_NAMESPACE = 'ESP-MDF'
 exit_code = 0
 
 
-class CursesHandler(logging.Handler):
-
-    def __init__(self, screen):
-        super().__init__()
-        self.screen = screen
-
-    def emit(self, record):
+def getch():
+    def _getch():
+        fd = sys.stdin.fileno()
+        old_settings = termios.tcgetattr(fd)
         try:
-            msg = self.format(record)
-            fs = "\n%s"
-            if record.levelname.lower() == 'critical':
-                self.screen.addstr(fs % msg, curses.A_STANDOUT)
-            else:
-                self.screen.addstr(fs % msg)
-            self.screen.refresh()
-        except (KeyboardInterrupt, SystemExit):
-            raise
-        except Exception:
-            self.handleError(record)
+            tty.setraw(fd)
+            ch = sys.stdin.read(1)
+        finally:
+            termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
+        return ch
+    return _getch()
 
 
 class SerialTestRunner:
@@ -279,33 +272,22 @@ def main(port, baudrate, include, exclude, tests_list, tests_execute):
         tests_execute=tests_execute,
     ))
 
-def _main(screen):
-    screen.nodelay(0)
-    screen.refresh()
-    maxy, maxx = screen.getmaxyx()
-    info_win = curses.newwin(maxy - 2, maxx // 2 - 2, 0, 1)
-    info_win.refresh()
-    info_win.scrollok(True)
-    info_win.idlok(True)
-    info_win.leaveok(True)
-    debug_win = curses.newwin(maxy - 2, maxx // 2 - 2, 0, maxx // 2 + 1)
-    debug_win.refresh()
-    debug_win.scrollok(True)
-    debug_win.idlok(True)
-    debug_win.leaveok(True)
+def _main():
+    global exit_code
 
-    handler = CursesHandler(info_win)
-    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+    handler = logging.StreamHandler()
+    formatter = logging.Formatter('%(levelname)-10s %(name)s - %(message)s')
     handler.setFormatter(formatter)
+
     logger.addHandler(handler)
 
     test_logs = logging.getLogger('test')
     test_logs.setLevel(logging.DEBUG)
-    test_logs.addHandler(CursesHandler(info_win))
+    test_logs.addHandler(handler)
 
     atlog = logging.getLogger('at')
     atlog.setLevel(logging.DEBUG)
-    atlog.addHandler(CursesHandler(debug_win))
+    atlog.addHandler(logging.StreamHandler())
 
     # monkey-patch Click's sys.exit
     _exit = sys.exit
@@ -314,18 +296,15 @@ def _main(screen):
         main()
     except Exception as e:
         logger.exception(e)
+        exit_code = 1
     sys.exit = _exit
 
-    logger.critical('Press any key to exit...')
-    screen.getch()
     sys.exit(exit_code)
 
 
 def run_tester():
     os.makedirs(TMP_DIR, exist_ok=True)
-    sys.stdout.write = lambda x, *args, **kwargs: logger.info(x.decode())
-    sys.stderr.write = lambda x, *args, **kwargs: logger.info(x.decode())
-    curses.wrapper(_main)
+    _main()
 
 
 if __name__ == '__main__':
