@@ -2,8 +2,8 @@
 import asyncio
 import logging
 import sys
-import termios
-import tty
+
+from teramesh_hardware_tester.tester import getch
 
 
 logger = logging.getLogger('test')
@@ -13,19 +13,6 @@ test_calibration_temperature = None
 test_calibration_humidity = None
 
 
-def getch():
-    def _getch():
-        fd = sys.stdin.fileno()
-        old_settings = termios.tcgetattr(fd)
-        try:
-            tty.setraw(fd)
-            ch = sys.stdin.read(1)
-        finally:
-            termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
-        return ch
-    return _getch()
-
-
 async def setup(AT):
     global test_calibration_temperature
     global test_calibration_humidity
@@ -73,27 +60,16 @@ async def test_led(AT):
 
 
 async def test_pir(AT):
-    logger.critical('Please prepare to WAVE AT PIR!')
-    for x in range(3, 0, -1):
-        logger.critical(f'{x}...')
-        await asyncio.sleep(1)
-    logger.critical('WAVE!')
+    logger.critical('Please WAVE AT PIR!')
     await AT.TESTPIR.execute()
-    result = await AT.TESTPIR.expect_reply()
+    result = await AT.TESTPIR.expect_reply(timeout=10)
     assert int(result) == 1, 'PIR did not detect waving'
 
 
 async def test_btn(AT):
     # TESTBTN handler waits for 5 seconds
     await AT.TESTBTN.execute()
-    logger.critical('Please prepare to PRESS DEV KEY!')
-    logger.critical('3...')
-    await asyncio.sleep(1)
-    logger.critical('2...')
-    await asyncio.sleep(1)
-    logger.critical('1...')
-    await asyncio.sleep(1)
-    logger.critical('PRESS!')
+    logger.critical('Please PRESS DEV KEY!')
     await AT.TESTBTN.expect_ok_or_error(timeout=15)
 
 
@@ -114,18 +90,24 @@ async def test_relays(AT):
     GPIO.setup(RELAY_COMMON_GPIO, GPIO.OUT)
     GPIO.output(RELAY_COMMON_GPIO, GPIO.HIGH)
     for relay_pin in RELAY_GPIO_MAP.values():
-        GPIO.setup(relay_pin, GPIO.IN)
+        GPIO.setup(relay_pin, GPIO.IN, pull_up_down=GPIO.PUD_DOWN)
 
     try:
+        await asyncio.sleep(0.5)
         await AT.TESTRELAY0.execute()
-        await AT.TESTRELAY0.expect_ok_or_error()
-        await asyncio.sleep(0.1)
-        for relay_no, relay_pin in RELAY_GPIO_MAP.items():
-            assert not GPIO.input(relay_pin), f'Relay {relay_no} did not close'
+        try:
+            await AT.TESTRELAY0.expect_ok_or_error()
+        except Exception:
+            pass
         for relay_no, relay_pin in RELAY_GPIO_MAP.items():
             await getattr(AT, f'TESTRELAY{relay_no}').execute()
             await getattr(AT, f'TESTRELAY{relay_no}').expect_ok_or_error()
-            await asyncio.sleep(0.1)
+            await asyncio.sleep(0.3)
             assert GPIO.input(relay_pin), f'Relay {relay_no} did not open'
+        await AT.TESTRELAY0.execute()
+        await AT.TESTRELAY0.expect_ok_or_error()
+        await asyncio.sleep(0.3)
+        for relay_no, relay_pin in RELAY_GPIO_MAP.items():
+            assert not GPIO.input(relay_pin), f'Relay {relay_no} did not close'
     finally:
         GPIO.cleanup()
